@@ -16,11 +16,18 @@ from .types import ContentType, ext_content_type
 from .util import TermCol, utf8len
 from . import response as res
 
-VERSION = "0.4.8"
+VERSION = "0.4.9"
 
 class Server:
 
-    def __init__(self, root_directory, SERVER_HOST = '0.0.0.0', SERVER_PORT = 8000, verbose=False, open_root=True, debug=False) -> None:
+    def __init__(self, root_directory,
+                    SERVER_HOST = '0.0.0.0',
+                    SERVER_PORT = 8000,
+                    verbose=False,
+                    open_root=True,
+                    debug=False,
+                    error_page_path = ""
+                ) -> None:
         # Define socket host and port
         self.SERVER_HOST = SERVER_HOST
         self.SERVER_PORT = SERVER_PORT
@@ -31,6 +38,7 @@ class Server:
         self.debug = debug
         self.static_resources:Set[str] = set()
         self.static_folders:Set[Path] = set()
+        self.error_page_path = error_page_path
 
     from .routehandler.router import _handle_route
 
@@ -123,7 +131,11 @@ class Server:
             else:
                 response = self._handle_route(reqpath, request_headers)
         except FileNotFoundError:
-            errfile = open(os.path.join(os.path.dirname(__file__), '404.html'))
+            errfile = ""
+            if self.error_page_path != "":
+                errfile = open(self.error_page_path)
+            else:
+                errfile = open(os.path.join(os.path.dirname(__file__), '404.html'))
             ErrContent = errfile.read()
             errfile.close()
             response = f'HTTP/1.1 404 NOT FOUND\n\n{ErrContent}'
